@@ -86,7 +86,7 @@ class Payments(Resource):
                 data.update({
                     "Source": {
                         "AccountNumber": payload.get("source", {}).get("account_number", None),
-                        "Amount": payload.get("source", {}).get("amount", None),
+                        "Amount": f'{payload.get("source", {}).get("amount", None)}',
                         "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                         "Narration": payload.get("transfer", {}).get("description", "")
                     }
@@ -106,7 +106,7 @@ class Payments(Resource):
                             "AccountNumber": destinations[i].get("account_number", None),
                             "BankCode": payload.get("transfer", {}).get("bank_code", None),
                             "BranchCode": payload.get("transfer", {}).get("branch_code", None),
-                            "Amount": destinations[i].get("amount", None),
+                            "Amount": f'{destinations[i].get("amount", None)}',
                             "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                             "Narration": payload.get("transfer", {}).get("description", "")
                         }
@@ -160,7 +160,7 @@ class Payments(Resource):
                         "Reference": f'{default_reference}',
                         "Currency": payload.get("transfer", {}).get("currency_code", None),
                         "Account": destination.get("account_number", None),
-                        "Amount": destination.get("amount", None),
+                        "Amount": f'{destination.get("amount", None)}',
                         "Narration": payload.get("transfer", {}).get("description", None),
                         "Transaction Date": payload.get("transfer", {}).get("date", date.today().strftime('%Y%m%d')).replace("-", ""),
                     })
@@ -184,7 +184,7 @@ class Payments(Resource):
                             "debit_currency": payload.get("transfer", {}).get("currency_code", ""),
                             "credit_currency": payload.get("transfer", {}).get("currency_code", ""),
                             "exchange_rate": 1,
-                            "transaction_amount": destination.get("amount", 0),
+                            "transaction_amount": f'{destination.get("amount", 0)}',
                             "transaction_date": payload.get("transfer", {}).get("date", ""),
                             "value_date": payload.get("transfer", {}).get("date", ""),
                             "narration": payload.get("transfer", {}).get("description", ""),
@@ -232,7 +232,7 @@ class Payments(Resource):
                 data.update({
                     "Source": {
                         "AccountNumber": f'{payload.get("source", {}).get("account_number", None)}',
-                        "Amount": payload.get("source", {}).get("amount", None),
+                        "Amount": f'{payload.get("source", {}).get("amount", None)}',
                         "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                         "Narration": payload.get("transfer", {}).get("description", "")
                     }
@@ -250,7 +250,7 @@ class Payments(Resource):
                         {
                             "ReferenceNumber": f'{default_reference}_1',
                             "MobileNumber": f'{destinations[i].get("mobile_number",None)}',
-                            "Amount": destinations[i].get("amount", None),
+                            "Amount": f'{destinations[i].get("amount", None)}',
                             "Narration": payload.get("transfer", {}).get("description", "")
                         }
                     )
@@ -304,7 +304,7 @@ class Payments(Resource):
                         },
                         "content": {
                             "cbs_reference": payload.get("transfer", {}).get("ift_reference", ""),
-                            "transaction_amount": int(float(destination.get("amount", 0))),
+                            "transaction_amount": f'{float(destination.get("amount", 0))}',
                             "credit_party": payload.get("source", {}).get("account_number", ""),
                             "customer_msisdn": destination.get("mobile_number", ""),
                             "customer_name": destination.get("name", ""),
@@ -332,7 +332,7 @@ class Payments(Resource):
                         "Reference": f'{default_reference}',
                         "Currency": payload.get("transfer", {}).get("currency_code", None),
                         "Account": destination.get("mobile_number", None),
-                        "Amount": destination.get("amount", None),
+                        "Amount": f'{destination.get("amount", None)}',
                         "Narration": payload.get("transfer", {}).get("description", None),
                         "Transaction Date": payload.get("transfer", {}).get("date", date.today().strftime('%Y%m%d')).replace("-", ""),
                         "Validation ID": f'{default_reference}',
@@ -393,7 +393,7 @@ class Payments(Resource):
                         "Reference": f'{default_reference}',
                         "Currency": payload.get("transfer", {}).get("currency_code", None),
                         "Account": destination.get("account_number", None),
-                        "Amount": destination.get("amount", None),
+                        "Amount": f'{destination.get("amount", None)}',
                         "Narration": payload.get("transfer", {}).get("description", None),
                         "Transaction Date": payload.get("transfer", {}).get("date", date.today().strftime('%Y%m%d')).replace("-", ""),
                     })
@@ -478,7 +478,7 @@ class Payments(Resource):
                 data.update({
                     "Source": {
                         "AccountNumber": payload.get("source", {}).get("account_number", None),
-                        "Amount": payload.get("source", {}).get("amount", None),
+                        "Amount": f'{payload.get("source", {}).get("amount", None)}',
                         "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                         "Narration": payload.get("transfer", {}).get("description", "")
                     }
@@ -497,7 +497,7 @@ class Payments(Resource):
                             "ReferenceNumber": f'{default_reference}_1',
                             "AccountNumber": destinations[i].get("account_number", None),
                             "BankCode": payload.get("transfer", {}).get("bank_code", None),
-                            "Amount": destinations[i].get("amount", None),
+                            "Amount": f'{destinations[i].get("amount", None)}',
                             "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                             "Narration": payload.get("transfer", {}).get("description", "")
                         }
@@ -553,7 +553,7 @@ class Payments(Resource):
                         "Reference": f'{default_reference}',
                         "Currency": payload.get("transfer", {}).get("currency_code", None),
                         "Account": destination.get("account_number", None),
-                        "Amount": destination.get("amount", None),
+                        "Amount": f'{destination.get("amount", None)}',
                         "Narration": payload.get("transfer", {}).get("description", None),
                         "Transaction Date": payload.get("transfer", {}).get("date", date.today().strftime('%Y%m%d')).replace("-", ""),
                     })
@@ -570,7 +570,7 @@ class Payments(Resource):
                 data.update({
                     "Source": {
                         "AccountNumber": payload.get("source", {}).get("account_number", None),
-                        "Amount": payload.get("source", {}).get("amount", None),
+                        "Amount": f'{payload.get("source", {}).get("amount", None)}',
                         "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                         "Narration": payload.get("transfer", {}).get("description", "")
                     }
@@ -588,7 +588,7 @@ class Payments(Resource):
                         {
                             "ReferenceNumber": f'{default_reference}_1',
                             "PhoneNumber": destinations[i].get("mobile_number", None),
-                            "Amount": destinations[i].get("amount", None),
+                            "Amount": f'{destinations[i].get("amount", None)}',
                             "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
                             "Narration": payload.get("transfer", {}).get("description", "")
                         }
@@ -677,7 +677,7 @@ class Payments(Resource):
                             "targetAccount": destination.get("account_number", ""),
                             "sortCode": payload.get("transfer", {}).get("sort_code", ""),
                             "currency": payload.get("transfer", {}).get("currency_code", ""),
-                            "value": destination.get("amount", 0),
+                            "value": f'{destination.get("amount", 0)}',
                             "referenceID": payload.get("transfer", {}).get("reference", ""),
                             "referenceMetaData": payload.get("transfer", {}).get("reference", ""),
                             "type":  payload.get("transfer", {}).get("type", ""),
@@ -716,7 +716,7 @@ class Payments(Resource):
                         },
                         "content": {
                             "timestamp": payload.get("transfer", {}).get("timestamp", ""),
-                            "transaction_amount": int(float(destination.get("amount", 0))),
+                            "transaction_amount": f'{float(destination.get("amount", 0))}',
                             "credit_party": payload.get("source", {}).get("account_number", ""),
                             "debit_party": destination.get("mobile_number", ""),
                             "customer_msisdn": destination.get("mobile_number", ""),
@@ -751,114 +751,116 @@ class Payments(Resource):
 
         if not isinstance(response_data,dict):
             data["response"]=response_data
+        
+        try:
+            
+            if super().get_bank_id() == super().COOP:
 
-        if super().get_bank_id() == super().COOP:
+                data["message"] = response_data.get("MessageDescription", "")
+                data["code"] = f'{response_data.get("MessageCode", "-1111111")}'
 
-            data["message"] = response_data.get("MessageDescription", "")
-            data["code"] = int(response_data.get("MessageCode", -1111111))
+                if 'MessageDescription' in response_data.keys():
+                    if response_data.get("MessageDescription", "") == "Full Success":
+                        data["message"] = "success"
+                    else:
+                        data["message"] = response_data.get(
+                            "MessageDescription", "")
 
-            if 'MessageDescription' in response_data.keys():
-                if response_data.get("MessageDescription", "") == "Full Success":
-                    data["message"] = "success"
-                else:
-                    data["message"] = response_data.get(
-                        "MessageDescription", "")
+                if 'MessageCode' in response_data.keys():
+                    data["code"] = f'{response_data.get("MessageCode", "-1111111")}'
 
-            if 'MessageCode' in response_data.keys():
-                data["code"] = int(response_data.get("MessageCode", -1111111))
+                if 'Destinations' in response_data.keys():
+                    if response_data.get("Destinations", [{}]) is not None:
 
-            if 'Destinations' in response_data.keys():
-                if response_data.get("Destinations", [{}]) is not None:
+                        data["transaction_id"] = response_data.get(
+                            "Destinations", [{}])[0].get("TransactionID", "")
 
-                    data["transaction_id"] = response_data.get(
-                        "Destinations", [{}])[0].get("TransactionID", "")
+                if 'MessageDateTime' in response_data.keys():
+                    data["date"] = response_data.get(
+                        "MessageDateTime", date.today().strftime('%d/%m/%y %H:%M:%S'))
 
-            if 'MessageDateTime' in response_data.keys():
-                data["date"] = response_data.get(
-                    "MessageDateTime", date.today().strftime('%d/%m/%y %H:%M:%S'))
+                if 'messageDescription' in response_data.keys():
+                    if response_data.get("messageDescription", "") == "Full Success":
+                        data["message"] = "success"
+                    else:
+                        data["message"] = response_data.get(
+                            "messageDescription", "")
 
-            if 'messageDescription' in response_data.keys():
-                if response_data.get("messageDescription", "") == "Full Success":
-                    data["message"] = "success"
-                else:
-                    data["message"] = response_data.get(
-                        "messageDescription", "")
+                if 'messageCode' in response_data.keys():
+                    data["code"] = f'{response_data.get("messageCode", "-1111111")}'
 
-            if 'messageCode' in response_data.keys():
-                data["code"] = int(response_data.get("messageCode", -1111111))
+                if 'destination' in response_data.keys():
+                    if response_data.get("destination", {}) is not None:
+                        data["transaction_id"] = response_data.get(
+                            "destination", {}).get("transactionID", "")
 
-            if 'destination' in response_data.keys():
-                if response_data.get("destination", {}) is not None:
-                    data["transaction_id"] = response_data.get(
-                        "destination", {}).get("transactionID", "")
+                if 'messageDateTime' in response_data.keys():
+                    data["date"] = response_data.get(
+                        "messageDateTime", date.today().strftime('%d/%m/%y %H:%M:%S'))
 
-            if 'messageDateTime' in response_data.keys():
-                data["date"] = response_data.get(
-                    "messageDateTime", date.today().strftime('%d/%m/%y %H:%M:%S'))
-
-        elif super().get_bank_id() == super().EQUITY:
-            data["message"] = response_data.get("message", "")
-            data["code"] = response_data.get("code", -1111111)
-            if 'mobileMoneyInfo' in response_data.keys():
-                data["transaction_id"] = response_data.get(
-                    "mobileMoneyInfo", {}).get("ThirdPartyTranID", "")
-            else:
-                data["transaction_id"] = response_data.get(
-                    "data", {}).get("transactionId", response_data.get("transactionId", response_data.get("transactionId ", "")))
-            data["date"] = response_data.get(
-                "date", date.today().strftime('%d/%m/%y %H:%M:%S'))
-        # If bank_id is DTB
-        elif super().get_bank_id() == super().DTB:
-            if super().get_operation() == super().IFT:
+            elif super().get_bank_id() == super().EQUITY:
                 data["message"] = response_data.get("message", "")
-                data["code"] = int(float(response_data.get(
-                    "content", {}).get("response_code", -1111111)))
-                data["transaction_id"] = response_data.get(
-                    "identifier", {}).get("trace_audit_number", "")
-                data["transaction_reference"] = response_data.get(
-                    "content", {}).get("transaction_reference", "")
-                data["date"] = date.today().strftime('%d/%m/%y %H:%M:%S')
-                if data["code"]:
-                    data["message"] = "Transaction Failed"
+                data["code"] = f'{response_data.get("code", "-1111111")}'
+                if 'mobileMoneyInfo' in response_data.keys():
+                    data["transaction_id"] = response_data.get(
+                        "mobileMoneyInfo", {}).get("ThirdPartyTranID", "")
                 else:
-                    data["message"] = "Success"
-            elif super().get_operation() == super().MOBILE_WALLET:
-                data["message"] = response_data.get(
-                    "content", {}).get("response_description", "")
-                data["code"] = int(float(response_data.get(
-                    "content", {}).get("response_code", -1111111)))
-                data["transaction_id"] = response_data.get(
-                    "content", {}).get("conversation_id", "")
-                data["transaction_reference"] = response_data.get(
-                    "content", {}).get("service_reference", "")
-            elif super().get_operation() == super().STK_PUSH:
-                data["message"] = response_data.get(
-                    "content", {}).get("response_description", "")
-                data["code"] = int(float(response_data.get(
-                    "content", {}).get("response_code", -1111111)))
-                data["transaction_id"] = response_data.get(
-                    "content", {}).get("merchant_request_id", "")
-                data["transaction_reference"] = response_data.get(
-                    "content", {}).get("service_reference", "")
-        # If bank_id is UBA
-        elif super().get_bank_id() == super().UBA:
-            if super().get_operation() == super().IFT:
-                resp_object = response_data.get("sendTransactionResponse", {}).get(
-                    "return", {}).get("C24TRANRES", {})
-                data["code"] = int(
-                    float(resp_object.get("ACTION_CODE", -1111111)))
-                data["transaction_id"] = resp_object.get("STAN", "")
-                data["transaction_reference"] = resp_object.get("STAN", "")
-                data["date"] = datetime.strptime(
-                    f'{resp_object.get("TRAN_DATE_TIME", None)}', '%Y%m%d%H%M%S').strftime('%d/%m/%y %H:%M:%S')
-                if data["code"]:
-                    data["message"] = "Transaction Failed"
-                else:
-                    data["message"] = "Success"
+                    data["transaction_id"] = response_data.get(
+                        "data", {}).get("transactionId", response_data.get("transactionId", response_data.get("transactionId ", "")))
+                data["date"] = response_data.get(
+                    "date", date.today().strftime('%d/%m/%y %H:%M:%S'))
+            # If bank_id is DTB
+            elif super().get_bank_id() == super().DTB:
+                if super().get_operation() == super().IFT:
+                    data["message"] = response_data.get("message", "")
+                    data["code"] = f'{int(float(response_data.get("content", {}).get("response_code"," -1111111")))}'
+                    data["transaction_id"] = response_data.get(
+                        "identifier", {}).get("trace_audit_number", "")
+                    data["transaction_reference"] = response_data.get(
+                        "content", {}).get("transaction_reference", "")
+                    data["date"] = date.today().strftime('%d/%m/%y %H:%M:%S')
+                    if int(data["code"]):
+                        data["message"] = "Transaction Failed"
+                    else:
+                        data["message"] = "Success"
+                elif super().get_operation() == super().MOBILE_WALLET:
+                    data["message"] = response_data.get(
+                        "content", {}).get("response_description", "")
+                    data["code"] = f'{int(float(response_data.get("content", {}).get("response_code", "-1111111")))}'
+                    data["transaction_id"] = response_data.get(
+                        "content", {}).get("conversation_id", "")
+                    data["transaction_reference"] = response_data.get(
+                        "content", {}).get("service_reference", "")
+                elif super().get_operation() == super().STK_PUSH:
+                    data["message"] = response_data.get(
+                        "content", {}).get("response_description", "")
+                    data["code"] = f'{int(float(response_data.get("content", {}).get("response_code", "-1111111")))}'
+                    data["transaction_id"] = response_data.get(
+                        "content", {}).get("merchant_request_id", "")
+                    data["transaction_reference"] = response_data.get(
+                        "content", {}).get("service_reference", "")
+            # If bank_id is UBA
+            elif super().get_bank_id() == super().UBA:
+                if super().get_operation() == super().IFT:
+                    resp_object = response_data.get("sendTransactionResponse", {}).get(
+                        "return", {}).get("C24TRANRES", {})
+                    data["code"] = f'{int(float(resp_object.get("ACTION_CODE", "-1111111")))}'
+                    data["transaction_id"] = resp_object.get("STAN", "")
+                    data["transaction_reference"] = resp_object.get("STAN", "")
+                    data["date"] = datetime.strptime(
+                        f'{resp_object.get("TRAN_DATE_TIME", None)}', '%Y%m%d%H%M%S').strftime('%d/%m/%y %H:%M:%S')
+                    if int(data["code"]):
+                        data["message"] = "Transaction Failed"
+                    else:
+                        data["message"] = "Success"
 
-        if bool(data):
-            # save the data returned to be sent back to a callback
-            self.simulate_callback(response=data)
-            return data
+            if bool(data):
+                # save the data returned to be sent back to a callback
+                self.simulate_callback(response=data)
+                return data
+
+        except Exception as e:
+            data["bank_sync_error"]=e
+            data["bank_core_response"]=super().response()
 
         return super().response()
