@@ -121,6 +121,11 @@ class Resource(API, Operations):
     def get_action(self):
         return self._action
 
+    def get_bank_payment_modes(self):
+        # use the Operation's super class to set the response that will be returned when this method is called
+        self._response = super().BANK_PAYMENT_MODES
+        return self
+
     # This is the data that can be sent back to a callback, it can be overriden
     # Each resource has the ability to decide what data can be sent back to a callback
     # This is the default standard of a sync callback data
@@ -420,14 +425,14 @@ class Resource(API, Operations):
 
             if ipn_data.get("bank_id", -1) == super().EQUITY:
 
-                if ipn_data.get("type", -1) in [super().OMN]:
+                if ipn_data.get("type", -1) in [super().OMN,super().POLARIS_CHANNEL,super().MISYS]:
 
                     response.update({
                         "message": f'{ipn_data.get("transaction", {}).get("status","")} {ipn_data.get("transaction", {}).get("remarks", "")}',
                         "code": f'{ipn_data.get("code", "-1")}',
-                        "transaction_id": ipn_data.get("transaction", {}).get("reference", ""),
+                        "transaction_id": ipn_data.get("bank", {}).get("reference", "").strip(),
                         "date": ipn_data.get("transaction", {}).get('date', ""),
-                        "account_reference": f'{ipn_data.get("customer", {}).get("reference", "")}',
+                        "account_reference": f'{ipn_data.get("transaction", {}).get("reference", "").strip()}',
                         "account_source": f"{ipn_data.get('bank',{}).get('account','')}",
                         "account_destination": ipn_data.get("transaction", {}).get("remarks", ""),
                         "amount": ipn_data.get("transaction", {}).get('amount', -1),
@@ -437,7 +442,7 @@ class Resource(API, Operations):
                     if ipn_data.get('bank', {}).get("transactionType", '').lower() == 'credit':
                         response["account_source"] = ipn_data.get(
                             "transaction", {}).get("remarks", "")
-                        response["account_destination"] = f"{ipn_data.get('bank',{}).get('account','')}",
+                        response["account_destination"] = f"{ipn_data.get('bank',{}).get('account','')}"
 
                     if int(response.get("code")) == 0:
                         response["completed"] = True
